@@ -69,6 +69,8 @@ C<static method push : void ($x_ndarray : L<R::NDArray::StringBuffer|SPVM::R::ND
 
 Performs C<$x_elem-E<gt>L<push|SPVM::StringBuffer/"push">($y_elem)> method on each element(named $x_elem, $y_elem) of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 If C<push> method throw an exceptions, $x_elem is unchanged.
 
 Exceptions:
@@ -77,7 +79,7 @@ The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is t
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 eq
 
